.. _models:
Models
========
In order to organise the functions of LyceanEM in a convenient manner, the major uses are arranged as either `Frequency Domain` or `Time Domain` models. The frequency domain models are more developed, but only consider a single spot frequency, and are hence inherently narrowband. The time domain models are much more capable, but have not yet been developed to offer all the same functionality, or support the full capability of the exsisting functions. A grounding in fourier transforms and signals analysis is required to get the best out of time domain modelling.

.. toctree::
    frequencydomainmodels
    timedomainmodels